package come.stormborntales.notevault.ui.screens

import android.util.Log
import androidx.compose.foundation.layout.Column
import androidx.compose.foundation.layout.Row
import androidx.compose.foundation.layout.Spacer
import androidx.compose.foundation.layout.fillMaxSize
import androidx.compose.foundation.layout.fillMaxWidth
import androidx.compose.foundation.layout.height
import androidx.compose.foundation.layout.padding
import androidx.compose.material3.Divider
import androidx.compose.material3.MaterialTheme
import androidx.compose.material3.OutlinedButton
import androidx.compose.material3.Switch
import androidx.compose.material3.Text
import androidx.compose.runtime.Composable
import androidx.compose.runtime.remember
import androidx.compose.runtime.rememberCoroutineScope
import androidx.compose.ui.Alignment
import androidx.compose.ui.Modifier
import androidx.compose.ui.unit.dp
import come.stormborntales.notevault.data.remote.ApiClient
import come.stormborntales.notevault.data.remote.ApiInterface
import come.stormborntales.notevault.data.remote.model.user.RegisterRequest
import kotlinx.coroutines.launch

@Composable
fun SettingsScreen() {
    val coroutineScope = rememberCoroutineScope()
    val syncApi = remember { ApiClient.retrofit.create(ApiInterface::class.java) }
    Column(
        modifier = Modifier
            .fillMaxSize()
            .padding(16.dp)
    ) {
        Text(
            text = "Einstellungen",
            style = MaterialTheme.typography.headlineMedium,
            modifier = Modifier.padding(bottom = 16.dp)
        )

        Divider()

        Spacer(modifier = Modifier.height(16.dp))

        // Beispielhafte Einstellung
        Row(
            verticalAlignment = Alignment.CenterVertically,
            modifier = Modifier.fillMaxWidth()
        ) {
            Text(
                text = "Dark Mode",
                modifier = Modifier.weight(1f),
                style = MaterialTheme.typography.bodyLarge
            )
            Switch(
                checked = false,
                onCheckedChange = { /* TODO: Dark Mode aktivieren */ }
            )
        }

        Spacer(modifier = Modifier.height(16.dp))

        Row(
            verticalAlignment = Alignment.CenterVertically,
            modifier = Modifier.fillMaxWidth()
        ) {
            Text(
                text = "Benachrichtigungen",
                modifier = Modifier.weight(1f),
                style = MaterialTheme.typography.bodyLarge
            )
            Switch(
                checked = true,
                onCheckedChange = { /* TODO: Benachrichtigungseinstellungen */ }
            )
        }

        Spacer(modifier = Modifier.height(32.dp))

        OutlinedButton(
            onClick = {
                coroutineScope.launch {
                    try {
                        val request = RegisterRequest("test@example.com", "123456")
                        val response = syncApi.register(request)

                        if(response.isSuccessful) {
                            Log.d("Response", "Response was successful")
                        } else {
                            Log.d("Response", "Error: ${response.errorBody()}")
                        }
                    } catch (e: Exception) {
                        println("Netzwerkfehler: ${e.message}")
                    }
                }
            },
            modifier = Modifier.fillMaxWidth()
        ) {
            Text("Registrierung testen")
        }
    }
}